==> cramr_ui_lib-1.0.17.tar.gz: test/settings/settings_view_test.dart <==
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:cramr_ui_lib/settings/settings_view.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

void main() {
  testWidgets('Test the settings screen', (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences.setMockInitialValues(
        <String, Object>{'cardinality.singularEnabled': true});
    SharedPreferences.setMockInitialValues(
        <String, Object>{'cardinality.pluralEnabled': true});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    SettingsController settingsController = SettingsController(
        SettingsService(prefs), ThemeMode.dark, prefs, NotificationService());
    settingsController.loadSettings();
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        // model.initialise(_randomIndicative, _randomPronouns, 'infinitive', 'fr',
        //     'translation', _mode, _tense);
        return model;
      },
      child: MaterialApp(
          home: SettingsView(
              controller: settingsController,
              safeBannerAdWidget: const SafeBannerAdWidget(
                adUnitId: '',
                adRequest: AdRequest(),
              ))),
    ));
    Finder enkelvoudFinder = find.text('Enkelvoud');
    expect(enkelvoudFinder, findsOneWidget);
    Finder meervoudFinder = find.text('Meervoud');
    expect(meervoudFinder, findsOneWidget);
    Finder hourFinder = find.text('07');
    expect(hourFinder, findsOneWidget);
    Finder colonFinder = find.text(':');
    expect(colonFinder, findsOneWidget);
    Finder minuteFinder = find.text('30');
    expect(minuteFinder, findsOneWidget);
  });
}

==> cramr_ui_lib-2.0.1.tar.gz: test/settings/settings_view_test.dart <==
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/settings/client_context.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:cramr_ui_lib/settings/settings_view.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

void main() {
  testWidgets('Test the settings screen', (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences.setMockInitialValues(
        <String, Object>{'cardinality.singularEnabled': true});
    SharedPreferences.setMockInitialValues(
        <String, Object>{'cardinality.pluralEnabled': true});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    SettingsController settingsController = SettingsController(
        SettingsService(prefs),
        ThemeMode.dark,
        prefs,
        NotificationService(),
        ClientContext(ClientApp.verbomatiqueSecondaire));
    settingsController.loadSettings();
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        // model.initialise(_randomIndicative, _randomPronouns, 'infinitive', 'fr',
        //     'translation', _mode, _tense);
        return model;
      },
      child: MaterialApp(
          home: SettingsView(
              controller: settingsController,
              safeBannerAdWidget: const SafeBannerAdWidget(
                adUnitId: '',
                adRequest: AdRequest(),
              ))),
    ));
    Finder enkelvoudFinder = find.text('Enkelvoud');
    expect(enkelvoudFinder, findsOneWidget);
    Finder meervoudFinder = find.text('Meervoud');
    expect(meervoudFinder, findsOneWidget);
    Finder hourFinder = find.text('07');
    expect(hourFinder, findsOneWidget);
    Finder colonFinder = find.text(':');
    expect(colonFinder, findsOneWidget);
    Finder minuteFinder = find.text('30');
    expect(minuteFinder, findsOneWidget);
  });
}
